@@ -22,7 +22,7 @@ def clustering(N,k):
 	means = kmeans.cluster_centers_
 
 	# Show results
-	plot.scatter(data[:, 0], data[:, 1], c=L)
+	plot.scatter(X[:, 0], X[:, 1], c=L)
 	plot.scatter(means[:, 0], means[:, 1], linewidths=2)
 	plot.show()
 
